==> calcite-cassandra-1.11.0-sources.jar: org/apache/calcite/adapter/cassandra/CassandraToEnumerableConverterRule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.adapter.cassandra;

import org.apache.calcite.adapter.enumerable.EnumerableConvention;
import org.apache.calcite.plan.RelTraitSet;
import org.apache.calcite.rel.RelNode;
import org.apache.calcite.rel.convert.ConverterRule;

/**
 * Rule to convert a relational expression from
 * {@link CassandraRel#CONVENTION} to {@link EnumerableConvention}.
 */
public class CassandraToEnumerableConverterRule extends ConverterRule {
  public static final ConverterRule INSTANCE =
    new CassandraToEnumerableConverterRule();

  private CassandraToEnumerableConverterRule() {
    super(RelNode.class, CassandraRel.CONVENTION, EnumerableConvention.INSTANCE,
        "CassandraToEnumerableConverterRule");
  }

  @Override public RelNode convert(RelNode rel) {
    RelTraitSet newTraitSet = rel.getTraitSet().replace(getOutConvention());
    return new CassandraToEnumerableConverter(rel.getCluster(), newTraitSet, rel);
  }
}

// End CassandraToEnumerableConverterRule.java

==> calcite-cassandra-1.15.0-sources.jar: org/apache/calcite/adapter/cassandra/CassandraToEnumerableConverterRule.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.adapter.cassandra;

import org.apache.calcite.adapter.enumerable.EnumerableConvention;
import org.apache.calcite.plan.RelTraitSet;
import org.apache.calcite.rel.RelNode;
import org.apache.calcite.rel.convert.ConverterRule;
import org.apache.calcite.rel.core.RelFactories;
import org.apache.calcite.tools.RelBuilderFactory;

import com.google.common.base.Predicates;

/**
 * Rule to convert a relational expression from
 * {@link CassandraRel#CONVENTION} to {@link EnumerableConvention}.
 */
public class CassandraToEnumerableConverterRule extends ConverterRule {
  public static final ConverterRule INSTANCE =
      new CassandraToEnumerableConverterRule(RelFactories.LOGICAL_BUILDER);

  /**
   * Creates a CassandraToEnumerableConverterRule.
   *
   * @param relBuilderFactory Builder for relational expressions
   */
  public CassandraToEnumerableConverterRule(
      RelBuilderFactory relBuilderFactory) {
    super(RelNode.class, Predicates.<RelNode>alwaysTrue(),
        CassandraRel.CONVENTION, EnumerableConvention.INSTANCE,
        relBuilderFactory, "CassandraToEnumerableConverterRule");
  }

  @Override public RelNode convert(RelNode rel) {
    RelTraitSet newTraitSet = rel.getTraitSet().replace(getOutConvention());
    return new CassandraToEnumerableConverter(rel.getCluster(), newTraitSet, rel);
  }
}

// End CassandraToEnumerableConverterRule.java
